from setuptools import setup

setup(name='GB_distributions2004',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['GB_distributions2004'],
      author= 'Nguyễn Đức Tâm',
      author_email = 'tamnd04@gmail.com',
      zip_safe=False)
